searchData={"items":[{"type":"module","title":"PhoenixTest.Case","doc":"ExUnit case module to assist with browser based tests.\nSee `PhoenixTest.Playwright` for more information.","ref":"PhoenixTest.Case.html"},{"type":"function","title":"PhoenixTest.Case.visit/2","doc":"","ref":"PhoenixTest.Case.html#visit/2"},{"type":"module","title":"PhoenixTest.Playwright","doc":"> #### Warning {: .warning}\n>\n> This driver is experimental.\n> If you don't need browser based tests, see `m:PhoenixTest#module-usage` on regular usage.\n\nExecute PhoenixTest cases in an actual browser via [Playwright](https://playwright.dev/).","ref":"PhoenixTest.Playwright.html"},{"type":"module","title":"Setup - PhoenixTest.Playwright","doc":"1. Install Playwright: `npm --prefix assets i -D playwright`\n2. Install browsers: `npm --prefix assets exec playwright install --with-deps`\n3. Add to `config/test.exs`: `config :phoenix_test, otp_app: :your_app, playwright: [cli: \"assets/node_modules/playwright/cli.js\"]`\n4. Add to `test/test_helpers.exs`: `Application.put_env(:phoenix_test, :base_url, YourAppWeb.Endpoint.url())`","ref":"PhoenixTest.Playwright.html#module-setup"},{"type":"module","title":"Usage - PhoenixTest.Playwright","doc":"```elixir\ndefmodule MyFeatureTest do\n  use PhoenixTest.Case, async: true\n  @moduletag :playwright\n\n  test \"heading\", %{conn: conn} do\n    conn\n    |> visit(\"/\")\n    |> assert_has(\"h1\", text: \"Heading\")\n  end\nend\n```\n\nAs shown above, you can use `m:ExUnit.Case#module-parameterized-tests` parameterized tests\nto run tests concurrently in different browsers.","ref":"PhoenixTest.Playwright.html#module-usage"},{"type":"module","title":"Known limitations and inconsistencies - PhoenixTest.Playwright","doc":"- `PhoenixTest.select/4` option `exact_option` is not supported\n- Playwright driver is less strict than `Live` and `Static` drivers. It does not raise errors\n  - when visiting a page that returns a `404` status\n  - when interactive elements such as forms and buttons are missing essential attributes (`phx-click`, `phx-submit`, `action`)\n- A few small bugs\n\nSee tests tagged with [`@tag playwright: false`](https://github.com/search?q=repo%3Agermsvel%2Fphoenix_test%20%22%40tag%20playwright%3A%20false%22&type=code)\nfor details.","ref":"PhoenixTest.Playwright.html#module-known-limitations-and-inconsistencies"},{"type":"module","title":"Configuration - PhoenixTest.Playwright","doc":"In `config/test.exs`:\n\n```elixir\nconfig :phoenix_test,\n  playwright: [\n    cli: \"assets/node_modules/playwright/cli.js\",\n    browser: [browser: :chromium, headless: System.get_env(\"PLAYWRIGHT_HEADLESS\", \"t\") in ~w(t true)],\n    trace: System.get_env(\"PLAYWRIGHT_TRACE\", \"false\") in ~w(t true),\n    trace_dir: \"tmp\"\n  ],\n  timeout_ms: 2000\n```","ref":"PhoenixTest.Playwright.html#module-configuration"},{"type":"module","title":"Ecto SQL.Sandbox - PhoenixTest.Playwright","doc":"`PhoenixTest.Case` automatically takes care of this.\nIt passes a user agent referencing your Ecto repos.\nThis allows for [concurrent browser tests](https://hexdocs.pm/phoenix_ecto/main.html#concurrent-browser-tests).\n\n```elixir\ndefmodule MyTest do\n  use PhoenixTest.Case, async: true\n```","ref":"PhoenixTest.Playwright.html#module-ecto-sql-sandbox"},{"type":"function","title":"PhoenixTest.Playwright.assert_has/2","doc":"","ref":"PhoenixTest.Playwright.html#assert_has/2"},{"type":"function","title":"PhoenixTest.Playwright.assert_has/3","doc":"","ref":"PhoenixTest.Playwright.html#assert_has/3"},{"type":"function","title":"PhoenixTest.Playwright.build/2","doc":"","ref":"PhoenixTest.Playwright.html#build/2"},{"type":"function","title":"PhoenixTest.Playwright.check/4","doc":"","ref":"PhoenixTest.Playwright.html#check/4"},{"type":"function","title":"PhoenixTest.Playwright.choose/4","doc":"","ref":"PhoenixTest.Playwright.html#choose/4"},{"type":"function","title":"PhoenixTest.Playwright.click/2","doc":"","ref":"PhoenixTest.Playwright.html#click/2"},{"type":"function","title":"PhoenixTest.Playwright.click/4","doc":"","ref":"PhoenixTest.Playwright.html#click/4"},{"type":"function","title":"PhoenixTest.Playwright.click_button/4","doc":"","ref":"PhoenixTest.Playwright.html#click_button/4"},{"type":"function","title":"PhoenixTest.Playwright.click_link/4","doc":"","ref":"PhoenixTest.Playwright.html#click_link/4"},{"type":"function","title":"PhoenixTest.Playwright.current_path/1","doc":"","ref":"PhoenixTest.Playwright.html#current_path/1"},{"type":"function","title":"PhoenixTest.Playwright.fill_in/4","doc":"","ref":"PhoenixTest.Playwright.html#fill_in/4"},{"type":"function","title":"PhoenixTest.Playwright.open_browser/2","doc":"","ref":"PhoenixTest.Playwright.html#open_browser/2"},{"type":"function","title":"PhoenixTest.Playwright.refute_has/2","doc":"","ref":"PhoenixTest.Playwright.html#refute_has/2"},{"type":"function","title":"PhoenixTest.Playwright.refute_has/3","doc":"","ref":"PhoenixTest.Playwright.html#refute_has/3"},{"type":"function","title":"PhoenixTest.Playwright.render_html/1","doc":"","ref":"PhoenixTest.Playwright.html#render_html/1"},{"type":"function","title":"PhoenixTest.Playwright.render_page_title/1","doc":"","ref":"PhoenixTest.Playwright.html#render_page_title/1"},{"type":"function","title":"PhoenixTest.Playwright.retry/2","doc":"","ref":"PhoenixTest.Playwright.html#retry/2"},{"type":"function","title":"PhoenixTest.Playwright.select/4","doc":"","ref":"PhoenixTest.Playwright.html#select/4"},{"type":"function","title":"PhoenixTest.Playwright.submit/1","doc":"","ref":"PhoenixTest.Playwright.html#submit/1"},{"type":"function","title":"PhoenixTest.Playwright.uncheck/4","doc":"","ref":"PhoenixTest.Playwright.html#uncheck/4"},{"type":"function","title":"PhoenixTest.Playwright.unwrap/2","doc":"","ref":"PhoenixTest.Playwright.html#unwrap/2"},{"type":"function","title":"PhoenixTest.Playwright.upload/5","doc":"","ref":"PhoenixTest.Playwright.html#upload/5"},{"type":"function","title":"PhoenixTest.Playwright.visit/2","doc":"","ref":"PhoenixTest.Playwright.html#visit/2"},{"type":"function","title":"PhoenixTest.Playwright.within/3","doc":"","ref":"PhoenixTest.Playwright.html#within/3"},{"type":"module","title":"PhoenixTest.Playwright.Browser","doc":"Interact with a Playwright `Browser`.\n\nThere is no official documentation, since this is considered Playwright internal.\n\nReferences:\n- https://github.com/microsoft/playwright/blob/main/packages/playwright-core/src/client/browser.ts","ref":"PhoenixTest.Playwright.Browser.html"},{"type":"function","title":"PhoenixTest.Playwright.Browser.new_context/2","doc":"Start a new browser context and return its `guid`.","ref":"PhoenixTest.Playwright.Browser.html#new_context/2"},{"type":"module","title":"PhoenixTest.Playwright.BrowserContext","doc":"Interact with a Playwright `BrowserContext`.\n\nThere is no official documentation, since this is considered Playwright internal.\n\nReferences:\n- https://github.com/microsoft/playwright/blob/main/packages/playwright-core/src/client/browserContext.ts","ref":"PhoenixTest.Playwright.BrowserContext.html"},{"type":"function","title":"PhoenixTest.Playwright.BrowserContext.new_page/1","doc":"Open a new browser page and return its `guid`.","ref":"PhoenixTest.Playwright.BrowserContext.html#new_page/1"},{"type":"function","title":"PhoenixTest.Playwright.BrowserContext.start_tracing/2","doc":"Start tracing. The results can be retrieved via `stop_tracing/2`.","ref":"PhoenixTest.Playwright.BrowserContext.html#start_tracing/2"},{"type":"function","title":"PhoenixTest.Playwright.BrowserContext.stop_tracing/2","doc":"Stop tracing and write zip file to specified output path.\n\nTrace can be viewed via either\n- `npx playwright show-trace trace.zip`\n- https://trace.playwright.dev","ref":"PhoenixTest.Playwright.BrowserContext.html#stop_tracing/2"},{"type":"module","title":"PhoenixTest.Playwright.Connection","doc":"Stateful, `GenServer` based connection to a Playwright node.js server.\nThe connection is established via `Playwright.Port`.\n\nYou won't usually have to use this module directly.\n`PhoenixTest.Case` uses this under the hood.","ref":"PhoenixTest.Playwright.Connection.html"},{"type":"function","title":"PhoenixTest.Playwright.Connection.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"PhoenixTest.Playwright.Connection.html#child_spec/1"},{"type":"function","title":"PhoenixTest.Playwright.Connection.ensure_started/1","doc":"Lazy launch. Only start the playwright server if actually needed by a test.","ref":"PhoenixTest.Playwright.Connection.html#ensure_started/1"},{"type":"function","title":"PhoenixTest.Playwright.Connection.initializer/1","doc":"Get the initializer data for a channel.","ref":"PhoenixTest.Playwright.Connection.html#initializer/1"},{"type":"function","title":"PhoenixTest.Playwright.Connection.launch_browser/2","doc":"Launch a browser and return its `guid`.","ref":"PhoenixTest.Playwright.Connection.html#launch_browser/2"},{"type":"function","title":"PhoenixTest.Playwright.Connection.post/1","doc":"Post a message and await the response.\nWe wait for an additional grace period after the timeout that we pass to playwright.","ref":"PhoenixTest.Playwright.Connection.html#post/1"},{"type":"function","title":"PhoenixTest.Playwright.Connection.received/1","doc":"Get all past received messages for a playwright `guid` (e.g. a `Frame`).\nThe internal map used to track these messages is never cleaned, it will keep on growing.\nSince we're dealing with (short-lived) tests, that should be fine.","ref":"PhoenixTest.Playwright.Connection.html#received/1"},{"type":"function","title":"PhoenixTest.Playwright.Connection.start_link/1","doc":"","ref":"PhoenixTest.Playwright.Connection.html#start_link/1"},{"type":"function","title":"PhoenixTest.Playwright.Connection.subscribe/2","doc":"Subscribe to messages for a guid and its descendants.","ref":"PhoenixTest.Playwright.Connection.html#subscribe/2"},{"type":"module","title":"PhoenixTest.Playwright.Frame","doc":"Interact with a Playwright `Frame` (usually the \"main\" frame of a browser page).\n\nThere is no official documentation, since this is considered Playwright internal.\n\nReferences:\n- https://github.com/microsoft/playwright/blob/main/packages/playwright-core/src/client/frame.ts","ref":"PhoenixTest.Playwright.Frame.html"},{"type":"function","title":"PhoenixTest.Playwright.Frame.check/3","doc":"","ref":"PhoenixTest.Playwright.Frame.html#check/3"},{"type":"function","title":"PhoenixTest.Playwright.Frame.click/3","doc":"","ref":"PhoenixTest.Playwright.Frame.html#click/3"},{"type":"function","title":"PhoenixTest.Playwright.Frame.content/1","doc":"","ref":"PhoenixTest.Playwright.Frame.html#content/1"},{"type":"function","title":"PhoenixTest.Playwright.Frame.evaluate/3","doc":"","ref":"PhoenixTest.Playwright.Frame.html#evaluate/3"},{"type":"function","title":"PhoenixTest.Playwright.Frame.expect/2","doc":"","ref":"PhoenixTest.Playwright.Frame.html#expect/2"},{"type":"function","title":"PhoenixTest.Playwright.Frame.fill/4","doc":"","ref":"PhoenixTest.Playwright.Frame.html#fill/4"},{"type":"function","title":"PhoenixTest.Playwright.Frame.goto/2","doc":"","ref":"PhoenixTest.Playwright.Frame.html#goto/2"},{"type":"function","title":"PhoenixTest.Playwright.Frame.inner_html/2","doc":"","ref":"PhoenixTest.Playwright.Frame.html#inner_html/2"},{"type":"function","title":"PhoenixTest.Playwright.Frame.press/3","doc":"","ref":"PhoenixTest.Playwright.Frame.html#press/3"},{"type":"function","title":"PhoenixTest.Playwright.Frame.select_option/4","doc":"","ref":"PhoenixTest.Playwright.Frame.html#select_option/4"},{"type":"function","title":"PhoenixTest.Playwright.Frame.set_input_files/4","doc":"","ref":"PhoenixTest.Playwright.Frame.html#set_input_files/4"},{"type":"function","title":"PhoenixTest.Playwright.Frame.title/1","doc":"","ref":"PhoenixTest.Playwright.Frame.html#title/1"},{"type":"function","title":"PhoenixTest.Playwright.Frame.uncheck/3","doc":"","ref":"PhoenixTest.Playwright.Frame.html#uncheck/3"},{"type":"function","title":"PhoenixTest.Playwright.Frame.url/1","doc":"","ref":"PhoenixTest.Playwright.Frame.html#url/1"},{"type":"function","title":"PhoenixTest.Playwright.Frame.wait_for_selector/2","doc":"","ref":"PhoenixTest.Playwright.Frame.html#wait_for_selector/2"},{"type":"module","title":"PhoenixTest.Playwright.Message","doc":"Parse playwright messages.\nA single `Port` message can contain multiple Playwright messages and/or a fraction of a message.\nSuch a message fraction is stored in `bufffer` and continued in the next `Port` message.","ref":"PhoenixTest.Playwright.Message.html"},{"type":"function","title":"PhoenixTest.Playwright.Message.parse/4","doc":"","ref":"PhoenixTest.Playwright.Message.html#parse/4"},{"type":"module","title":"PhoenixTest.Playwright.Port","doc":"Start a Playwright node.js server and communicate with it via a `Port`.","ref":"PhoenixTest.Playwright.Port.html"},{"type":"function","title":"PhoenixTest.Playwright.Port.open/1","doc":"","ref":"PhoenixTest.Playwright.Port.html#open/1"},{"type":"function","title":"PhoenixTest.Playwright.Port.parse/2","doc":"","ref":"PhoenixTest.Playwright.Port.html#parse/2"},{"type":"function","title":"PhoenixTest.Playwright.Port.post/2","doc":"","ref":"PhoenixTest.Playwright.Port.html#post/2"},{"type":"module","title":"PhoenixTest.Playwright.Selector","doc":"Playright supports different types of locators: CSS, XPath, internal.\n\nThey can mixed and matched by chaining the together.\n\nAlso, you can register [custom selector engines](https://playwright.dev/docs/extensibility#custom-selector-engines)\nthat run right in the browser (Javascript).\n\nThere is no official documentation, since this is considered Playwright internal.\n\nReferences:\n- https://playwright.dev/docs/other-locators\n- https://github.com/microsoft/playwright/blob/main/packages/playwright-core/src/client/locator.ts\n- https://github.com/microsoft/playwright/blob/main/packages/playwright-core/src/utils/isomorphic/locatorUtils.ts","ref":"PhoenixTest.Playwright.Selector.html"},{"type":"function","title":"PhoenixTest.Playwright.Selector.and/2","doc":"","ref":"PhoenixTest.Playwright.Selector.html#and/2"},{"type":"function","title":"PhoenixTest.Playwright.Selector.at/1","doc":"","ref":"PhoenixTest.Playwright.Selector.html#at/1"},{"type":"function","title":"PhoenixTest.Playwright.Selector.build/1","doc":"","ref":"PhoenixTest.Playwright.Selector.html#build/1"},{"type":"function","title":"PhoenixTest.Playwright.Selector.button/2","doc":"","ref":"PhoenixTest.Playwright.Selector.html#button/2"},{"type":"function","title":"PhoenixTest.Playwright.Selector.concat/2","doc":"","ref":"PhoenixTest.Playwright.Selector.html#concat/2"},{"type":"function","title":"PhoenixTest.Playwright.Selector.css/1","doc":"","ref":"PhoenixTest.Playwright.Selector.html#css/1"},{"type":"function","title":"PhoenixTest.Playwright.Selector.label/2","doc":"","ref":"PhoenixTest.Playwright.Selector.html#label/2"},{"type":"function","title":"PhoenixTest.Playwright.Selector.link/2","doc":"","ref":"PhoenixTest.Playwright.Selector.html#link/2"},{"type":"function","title":"PhoenixTest.Playwright.Selector.menuitem/2","doc":"","ref":"PhoenixTest.Playwright.Selector.html#menuitem/2"},{"type":"function","title":"PhoenixTest.Playwright.Selector.none/0","doc":"","ref":"PhoenixTest.Playwright.Selector.html#none/0"},{"type":"function","title":"PhoenixTest.Playwright.Selector.role/3","doc":"","ref":"PhoenixTest.Playwright.Selector.html#role/3"},{"type":"function","title":"PhoenixTest.Playwright.Selector.text/2","doc":"","ref":"PhoenixTest.Playwright.Selector.html#text/2"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}